4.36. umbra.processing — Umbra 1.0.9 documentation

# 4.36. umbra.processing

processing.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `Processing` class.

Others:

## 4.36.1. Module Attributes

`umbra.processing.` `LOGGER`

`umbra.processing.` `UI_FILE`

## 4.36.2. Classes

class `umbra.processing.` `Processing`(parent, *args, **kwargs)

  Bases: `foundations.ui.common.QWidget`

  Defines the Application processing status bar widget.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent. *args (*) – Arguments. **kwargs (**) – Keywords arguments.

  `container`

    Property for self.__container attribute.

    Returns: | self.__container.
    Return type: | QObject